# Beepy Bluetooth Manager

A simplified Bluetooth manager for Beepy devices.


## Todo

- [ ] No lag on startup
- [ ] Notification for successful/failed connection
- [ ] Auto-rescan/update list of devices
- [ ] Highlight if already connected to device
- [ ] Auto-connect profiles
- [ ] Loading spinner while scanning for devices
- [ ] Test on fresh device
